@@ -14,9 +14,8 @@ namespace a11y {
 /**
  * HTML canvas accessible (html:canvas).
  */
-class HTMLCanvasAccessible : public HyperTextAccessibleWrap
-{
-public:
+class HTMLCanvasAccessible : public HyperTextAccessibleWrap {
+ public:
   HTMLCanvasAccessible(nsIContent* aContent, DocAccessible* aDoc);
 
   // nsISupports
@@ -26,11 +25,11 @@ public:
   // Accessible
   virtual a11y::role NativeRole() override;
 
-protected:
-  virtual ~HTMLCanvasAccessible() { }
+ protected:
+  virtual ~HTMLCanvasAccessible() {}
 };
 
-} // namespace a11y
-} // namespace mozilla
+}  // namespace a11y
+}  // namespace mozilla
 
 #endif
