@@ -36,13 +36,11 @@ NS_IMPL_RELEASE_INHERITED(xpcAccessibleHyperText, xpcAccessibleGeneric)
 // nsIAccessibleText
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::GetCharacterCount(int32_t* aCharacterCount)
-{
+xpcAccessibleHyperText::GetCharacterCount(int32_t* aCharacterCount) {
   NS_ENSURE_ARG_POINTER(aCharacterCount);
   *aCharacterCount = 0;
 
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     *aCharacterCount = Intl()->CharacterCount();
@@ -58,12 +56,10 @@ xpcAccessibleHyperText::GetCharacterCount(int32_t* aCharacterCount)
 
 NS_IMETHODIMP
 xpcAccessibleHyperText::GetText(int32_t aStartOffset, int32_t aEndOffset,
-                                nsAString& aText)
-{
+                                nsAString& aText) {
   aText.Truncate();
 
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     Intl()->TextSubstring(aStartOffset, aEndOffset, aText);
@@ -76,19 +72,15 @@ xpcAccessibleHyperText::GetText(int32_t aStartOffset, int32_t aEndOffset,
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::GetTextBeforeOffset(int32_t aOffset,
-                                            AccessibleTextBoundary aBoundaryType,
-                                            int32_t* aStartOffset,
-                                            int32_t* aEndOffset,
-                                            nsAString& aText)
-{
+xpcAccessibleHyperText::GetTextBeforeOffset(
+    int32_t aOffset, AccessibleTextBoundary aBoundaryType,
+    int32_t* aStartOffset, int32_t* aEndOffset, nsAString& aText) {
   NS_ENSURE_ARG_POINTER(aStartOffset);
   NS_ENSURE_ARG_POINTER(aEndOffset);
   *aStartOffset = *aEndOffset = 0;
   aText.Truncate();
 
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     Intl()->TextBeforeOffset(aOffset, aBoundaryType, aStartOffset, aEndOffset,
@@ -106,23 +98,21 @@ NS_IMETHODIMP
 xpcAccessibleHyperText::GetTextAtOffset(int32_t aOffset,
                                         AccessibleTextBoundary aBoundaryType,
                                         int32_t* aStartOffset,
-                                        int32_t* aEndOffset, nsAString& aText)
-{
+                                        int32_t* aEndOffset, nsAString& aText) {
   NS_ENSURE_ARG_POINTER(aStartOffset);
   NS_ENSURE_ARG_POINTER(aEndOffset);
   *aStartOffset = *aEndOffset = 0;
   aText.Truncate();
 
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     Intl()->TextAtOffset(aOffset, aBoundaryType, aStartOffset, aEndOffset,
                          aText);
   } else {
     nsString text;
-    mIntl.AsProxy()->GetTextAtOffset(aOffset, aBoundaryType, text,
-                                     aStartOffset, aEndOffset);
+    mIntl.AsProxy()->GetTextAtOffset(aOffset, aBoundaryType, text, aStartOffset,
+                                     aEndOffset);
     aText = text;
   }
   return NS_OK;
@@ -132,15 +122,14 @@ NS_IMETHODIMP
 xpcAccessibleHyperText::GetTextAfterOffset(int32_t aOffset,
                                            AccessibleTextBoundary aBoundaryType,
                                            int32_t* aStartOffset,
-                                           int32_t* aEndOffset, nsAString& aText)
-{
+                                           int32_t* aEndOffset,
+                                           nsAString& aText) {
   NS_ENSURE_ARG_POINTER(aStartOffset);
   NS_ENSURE_ARG_POINTER(aEndOffset);
   *aStartOffset = *aEndOffset = 0;
   aText.Truncate();
 
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     Intl()->TextAfterOffset(aOffset, aBoundaryType, aStartOffset, aEndOffset,
@@ -156,13 +145,11 @@ xpcAccessibleHyperText::GetTextAfterOffset(int32_t aOffset,
 
 NS_IMETHODIMP
 xpcAccessibleHyperText::GetCharacterAtOffset(int32_t aOffset,
-                                             char16_t* aCharacter)
-{
+                                             char16_t* aCharacter) {
   NS_ENSURE_ARG_POINTER(aCharacter);
   *aCharacter = L'\0';
 
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     *aCharacter = Intl()->CharAt(aOffset);
@@ -177,20 +164,16 @@ xpcAccessibleHyperText::GetCharacterAtOffset(int32_t aOffset,
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::GetTextAttributes(bool aIncludeDefAttrs,
-                                          int32_t aOffset,
-                                          int32_t* aStartOffset,
-                                          int32_t* aEndOffset,
-                                          nsIPersistentProperties** aAttributes)
-{
+xpcAccessibleHyperText::GetTextAttributes(
+    bool aIncludeDefAttrs, int32_t aOffset, int32_t* aStartOffset,
+    int32_t* aEndOffset, nsIPersistentProperties** aAttributes) {
   NS_ENSURE_ARG_POINTER(aStartOffset);
   NS_ENSURE_ARG_POINTER(aEndOffset);
   NS_ENSURE_ARG_POINTER(aAttributes);
   *aStartOffset = *aEndOffset = 0;
   *aAttributes = nullptr;
 
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   nsCOMPtr<nsIPersistentProperties> props;
   if (mIntl.IsAccessible()) {
@@ -202,7 +185,7 @@ xpcAccessibleHyperText::GetTextAttributes(bool aIncludeDefAttrs,
 #else
     AutoTArray<Attribute, 10> attrs;
     mIntl.AsProxy()->TextAttributes(aIncludeDefAttrs, aOffset, &attrs,
-        aStartOffset, aEndOffset);
+                                    aStartOffset, aEndOffset);
     uint32_t attrCount = attrs.Length();
     nsAutoString unused;
     for (uint32_t i = 0; i < attrCount; i++) {
@@ -216,13 +199,12 @@ xpcAccessibleHyperText::GetTextAttributes(bool aIncludeDefAttrs,
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::GetDefaultTextAttributes(nsIPersistentProperties** aAttributes)
-{
+xpcAccessibleHyperText::GetDefaultTextAttributes(
+    nsIPersistentProperties** aAttributes) {
   NS_ENSURE_ARG_POINTER(aAttributes);
   *aAttributes = nullptr;
 
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   nsCOMPtr<nsIPersistentProperties> props;
   if (mIntl.IsAccessible()) {
@@ -246,19 +228,17 @@ xpcAccessibleHyperText::GetDefaultTextAttributes(nsIPersistentProperties** aAttr
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::GetCharacterExtents(int32_t aOffset,
-                                            int32_t* aX, int32_t* aY,
-                                            int32_t* aWidth, int32_t* aHeight,
-                                            uint32_t aCoordType)
-{
+xpcAccessibleHyperText::GetCharacterExtents(int32_t aOffset, int32_t* aX,
+                                            int32_t* aY, int32_t* aWidth,
+                                            int32_t* aHeight,
+                                            uint32_t aCoordType) {
   NS_ENSURE_ARG_POINTER(aX);
   NS_ENSURE_ARG_POINTER(aY);
   NS_ENSURE_ARG_POINTER(aWidth);
   NS_ENSURE_ARG_POINTER(aHeight);
   *aX = *aY = *aWidth = *aHeight;
 
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   nsIntRect rect;
   if (mIntl.IsAccessible()) {
@@ -275,19 +255,17 @@ xpcAccessibleHyperText::GetCharacterExtents(int32_t aOffset,
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::GetRangeExtents(int32_t aStartOffset, int32_t aEndOffset,
-                                        int32_t* aX, int32_t* aY,
-                                        int32_t* aWidth, int32_t* aHeight,
-                                        uint32_t aCoordType)
-{
+xpcAccessibleHyperText::GetRangeExtents(int32_t aStartOffset,
+                                        int32_t aEndOffset, int32_t* aX,
+                                        int32_t* aY, int32_t* aWidth,
+                                        int32_t* aHeight, uint32_t aCoordType) {
   NS_ENSURE_ARG_POINTER(aX);
   NS_ENSURE_ARG_POINTER(aY);
   NS_ENSURE_ARG_POINTER(aWidth);
   NS_ENSURE_ARG_POINTER(aHeight);
   *aX = *aY = *aWidth = *aHeight = 0;
 
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   nsIntRect rect;
   if (mIntl.IsAccessible()) {
@@ -305,13 +283,12 @@ xpcAccessibleHyperText::GetRangeExtents(int32_t aStartOffset, int32_t aEndOffset
 
 NS_IMETHODIMP
 xpcAccessibleHyperText::GetOffsetAtPoint(int32_t aX, int32_t aY,
-                                         uint32_t aCoordType, int32_t* aOffset)
-{
+                                         uint32_t aCoordType,
+                                         int32_t* aOffset) {
   NS_ENSURE_ARG_POINTER(aOffset);
   *aOffset = -1;
 
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     *aOffset = Intl()->OffsetAtPoint(aX, aY, aCoordType);
@@ -326,13 +303,11 @@ xpcAccessibleHyperText::GetOffsetAtPoint(int32_t aX, int32_t aY,
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::GetCaretOffset(int32_t* aCaretOffset)
-{
+xpcAccessibleHyperText::GetCaretOffset(int32_t* aCaretOffset) {
   NS_ENSURE_ARG_POINTER(aCaretOffset);
   *aCaretOffset = -1;
 
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     *aCaretOffset = Intl()->CaretOffset();
@@ -343,10 +318,8 @@ xpcAccessibleHyperText::GetCaretOffset(int32_t* aCaretOffset)
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::SetCaretOffset(int32_t aCaretOffset)
-{
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+xpcAccessibleHyperText::SetCaretOffset(int32_t aCaretOffset) {
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     Intl()->SetCaretOffset(aCaretOffset);
@@ -357,13 +330,11 @@ xpcAccessibleHyperText::SetCaretOffset(int32_t aCaretOffset)
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::GetSelectionCount(int32_t* aSelectionCount)
-{
+xpcAccessibleHyperText::GetSelectionCount(int32_t* aSelectionCount) {
   NS_ENSURE_ARG_POINTER(aSelectionCount);
   *aSelectionCount = 0;
 
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     *aSelectionCount = Intl()->SelectionCount();
@@ -380,21 +351,17 @@ xpcAccessibleHyperText::GetSelectionCount(int32_t* aSelectionCount)
 NS_IMETHODIMP
 xpcAccessibleHyperText::GetSelectionBounds(int32_t aSelectionNum,
                                            int32_t* aStartOffset,
-                                           int32_t* aEndOffset)
-{
+                                           int32_t* aEndOffset) {
   NS_ENSURE_ARG_POINTER(aStartOffset);
   NS_ENSURE_ARG_POINTER(aEndOffset);
   *aStartOffset = *aEndOffset = 0;
 
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
-  if (aSelectionNum < 0)
-    return NS_ERROR_INVALID_ARG;
+  if (aSelectionNum < 0) return NS_ERROR_INVALID_ARG;
 
   if (mIntl.IsAccessible()) {
-    if (aSelectionNum >= Intl()->SelectionCount())
-      return NS_ERROR_INVALID_ARG;
+    if (aSelectionNum >= Intl()->SelectionCount()) return NS_ERROR_INVALID_ARG;
 
     Intl()->SelectionBoundsAt(aSelectionNum, aStartOffset, aEndOffset);
   } else {
@@ -412,37 +379,32 @@ xpcAccessibleHyperText::GetSelectionBounds(int32_t aSelectionNum,
 NS_IMETHODIMP
 xpcAccessibleHyperText::SetSelectionBounds(int32_t aSelectionNum,
                                            int32_t aStartOffset,
-                                           int32_t aEndOffset)
-{
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+                                           int32_t aEndOffset) {
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
-  if (aSelectionNum < 0)
-    return NS_ERROR_INVALID_ARG;
+  if (aSelectionNum < 0) return NS_ERROR_INVALID_ARG;
 
   if (mIntl.IsAccessible()) {
-      if (!Intl()->SetSelectionBoundsAt(aSelectionNum, aStartOffset,
-                                        aEndOffset)) {
-        return NS_ERROR_INVALID_ARG;
-      }
+    if (!Intl()->SetSelectionBoundsAt(aSelectionNum, aStartOffset,
+                                      aEndOffset)) {
+      return NS_ERROR_INVALID_ARG;
+    }
   } else {
 #if defined(XP_WIN)
     return NS_ERROR_NOT_IMPLEMENTED;
 #else
-      if (!mIntl.AsProxy()->SetSelectionBoundsAt(aSelectionNum, aStartOffset,
-                                                aEndOffset)) {
-        return NS_ERROR_INVALID_ARG;
-      }
+    if (!mIntl.AsProxy()->SetSelectionBoundsAt(aSelectionNum, aStartOffset,
+                                               aEndOffset)) {
+      return NS_ERROR_INVALID_ARG;
+    }
 #endif
   }
   return NS_OK;
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::AddSelection(int32_t aStartOffset, int32_t aEndOffset)
-{
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+xpcAccessibleHyperText::AddSelection(int32_t aStartOffset, int32_t aEndOffset) {
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     Intl()->AddToSelection(aStartOffset, aEndOffset);
@@ -453,10 +415,8 @@ xpcAccessibleHyperText::AddSelection(int32_t aStartOffset, int32_t aEndOffset)
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::RemoveSelection(int32_t aSelectionNum)
-{
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+xpcAccessibleHyperText::RemoveSelection(int32_t aSelectionNum) {
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     Intl()->RemoveFromSelection(aSelectionNum);
@@ -469,10 +429,8 @@ xpcAccessibleHyperText::RemoveSelection(int32_t aSelectionNum)
 NS_IMETHODIMP
 xpcAccessibleHyperText::ScrollSubstringTo(int32_t aStartOffset,
                                           int32_t aEndOffset,
-                                          uint32_t aScrollType)
-{
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+                                          uint32_t aScrollType) {
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     Intl()->ScrollSubstringTo(aStartOffset, aEndOffset, aScrollType);
@@ -486,10 +444,8 @@ NS_IMETHODIMP
 xpcAccessibleHyperText::ScrollSubstringToPoint(int32_t aStartOffset,
                                                int32_t aEndOffset,
                                                uint32_t aCoordinateType,
-                                               int32_t aX, int32_t aY)
-{
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+                                               int32_t aX, int32_t aY) {
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     Intl()->ScrollSubstringToPoint(aStartOffset, aEndOffset, aCoordinateType,
@@ -502,13 +458,11 @@ xpcAccessibleHyperText::ScrollSubstringToPoint(int32_t aStartOffset,
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::GetEnclosingRange(nsIAccessibleTextRange** aRange)
-{
+xpcAccessibleHyperText::GetEnclosingRange(nsIAccessibleTextRange** aRange) {
   NS_ENSURE_ARG_POINTER(aRange);
   *aRange = nullptr;
 
-  if (!Intl())
-    return NS_ERROR_FAILURE;
+  if (!Intl()) return NS_ERROR_FAILURE;
 
   RefPtr<xpcAccessibleTextRange> range = new xpcAccessibleTextRange;
   Intl()->EnclosingRange(range->mRange);
@@ -521,17 +475,15 @@ xpcAccessibleHyperText::GetEnclosingRange(nsIAccessibleTextRange** aRange)
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::GetSelectionRanges(nsIArray** aRanges)
-{
+xpcAccessibleHyperText::GetSelectionRanges(nsIArray** aRanges) {
   NS_ENSURE_ARG_POINTER(aRanges);
   *aRanges = nullptr;
 
-  if (!Intl())
-    return NS_ERROR_FAILURE;
+  if (!Intl()) return NS_ERROR_FAILURE;
 
   nsresult rv = NS_OK;
   nsCOMPtr<nsIMutableArray> xpcRanges =
-    do_CreateInstance(NS_ARRAY_CONTRACTID, &rv);
+      do_CreateInstance(NS_ARRAY_CONTRACTID, &rv);
   NS_ENSURE_SUCCESS(rv, rv);
 
   AutoTArray<TextRange, 1> ranges;
@@ -545,17 +497,15 @@ xpcAccessibleHyperText::GetSelectionRanges(nsIArray** aRanges)
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::GetVisibleRanges(nsIArray** aRanges)
-{
+xpcAccessibleHyperText::GetVisibleRanges(nsIArray** aRanges) {
   NS_ENSURE_ARG_POINTER(aRanges);
   *aRanges = nullptr;
 
-  if (!Intl())
-    return NS_ERROR_FAILURE;
+  if (!Intl()) return NS_ERROR_FAILURE;
 
   nsresult rv = NS_OK;
   nsCOMPtr<nsIMutableArray> xpcRanges =
-    do_CreateInstance(NS_ARRAY_CONTRACTID, &rv);
+      do_CreateInstance(NS_ARRAY_CONTRACTID, &rv);
   NS_ENSURE_SUCCESS(rv, rv);
 
   nsTArray<TextRange> ranges;
@@ -570,20 +520,17 @@ xpcAccessibleHyperText::GetVisibleRanges(nsIArray** aRanges)
 
 NS_IMETHODIMP
 xpcAccessibleHyperText::GetRangeByChild(nsIAccessible* aChild,
-                                        nsIAccessibleTextRange** aRange)
-{
+                                        nsIAccessibleTextRange** aRange) {
   NS_ENSURE_ARG_POINTER(aRange);
   *aRange = nullptr;
 
-  if (!Intl())
-    return NS_ERROR_FAILURE;
+  if (!Intl()) return NS_ERROR_FAILURE;
 
   Accessible* child = aChild->ToInternalAccessible();
   if (child) {
     RefPtr<xpcAccessibleTextRange> range = new xpcAccessibleTextRange;
     Intl()->RangeByChild(child, range->mRange);
-    if (range->mRange.IsValid())
-      range.forget(aRange);
+    if (range->mRange.IsValid()) range.forget(aRange);
   }
 
   return NS_OK;
@@ -591,18 +538,15 @@ xpcAccessibleHyperText::GetRangeByChild(nsIAccessible* aChild,
 
 NS_IMETHODIMP
 xpcAccessibleHyperText::GetRangeAtPoint(int32_t aX, int32_t aY,
-                                        nsIAccessibleTextRange** aRange)
-{
+                                        nsIAccessibleTextRange** aRange) {
   NS_ENSURE_ARG_POINTER(aRange);
   *aRange = nullptr;
 
-  if (!Intl())
-    return NS_ERROR_FAILURE;
+  if (!Intl()) return NS_ERROR_FAILURE;
 
   RefPtr<xpcAccessibleTextRange> range = new xpcAccessibleTextRange;
   Intl()->RangeAtPoint(aX, aY, range->mRange);
-  if (range->mRange.IsValid())
-    range.forget(aRange);
+  if (range->mRange.IsValid()) range.forget(aRange);
 
   return NS_OK;
 }
@@ -611,10 +555,8 @@ xpcAccessibleHyperText::GetRangeAtPoint(int32_t aX, int32_t aY,
 // nsIAccessibleEditableText
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::SetTextContents(const nsAString& aText)
-{
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+xpcAccessibleHyperText::SetTextContents(const nsAString& aText) {
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     Intl()->ReplaceText(aText);
@@ -630,10 +572,8 @@ xpcAccessibleHyperText::SetTextContents(const nsAString& aText)
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::InsertText(const nsAString& aText, int32_t aOffset)
-{
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+xpcAccessibleHyperText::InsertText(const nsAString& aText, int32_t aOffset) {
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     Intl()->InsertText(aText, aOffset);
@@ -649,10 +589,8 @@ xpcAccessibleHyperText::InsertText(const nsAString& aText, int32_t aOffset)
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::CopyText(int32_t aStartOffset, int32_t aEndOffset)
-{
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+xpcAccessibleHyperText::CopyText(int32_t aStartOffset, int32_t aEndOffset) {
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     Intl()->CopyText(aStartOffset, aEndOffset);
@@ -667,10 +605,8 @@ xpcAccessibleHyperText::CopyText(int32_t aStartOffset, int32_t aEndOffset)
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::CutText(int32_t aStartOffset, int32_t aEndOffset)
-{
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+xpcAccessibleHyperText::CutText(int32_t aStartOffset, int32_t aEndOffset) {
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     Intl()->CutText(aStartOffset, aEndOffset);
@@ -685,10 +621,8 @@ xpcAccessibleHyperText::CutText(int32_t aStartOffset, int32_t aEndOffset)
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::DeleteText(int32_t aStartOffset, int32_t aEndOffset)
-{
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+xpcAccessibleHyperText::DeleteText(int32_t aStartOffset, int32_t aEndOffset) {
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     Intl()->DeleteText(aStartOffset, aEndOffset);
@@ -703,10 +637,8 @@ xpcAccessibleHyperText::DeleteText(int32_t aStartOffset, int32_t aEndOffset)
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::PasteText(int32_t aOffset)
-{
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+xpcAccessibleHyperText::PasteText(int32_t aOffset) {
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     Intl()->PasteText(aOffset);
@@ -724,13 +656,11 @@ xpcAccessibleHyperText::PasteText(int32_t aOffset)
 // nsIAccessibleHyperText
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::GetLinkCount(int32_t* aLinkCount)
-{
+xpcAccessibleHyperText::GetLinkCount(int32_t* aLinkCount) {
   NS_ENSURE_ARG_POINTER(aLinkCount);
   *aLinkCount = 0;
 
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     *aLinkCount = Intl()->LinkCount();
@@ -745,13 +675,12 @@ xpcAccessibleHyperText::GetLinkCount(int32_t* aLinkCount)
 }
 
 NS_IMETHODIMP
-xpcAccessibleHyperText::GetLinkAt(int32_t aIndex, nsIAccessibleHyperLink** aLink)
-{
+xpcAccessibleHyperText::GetLinkAt(int32_t aIndex,
+                                  nsIAccessibleHyperLink** aLink) {
   NS_ENSURE_ARG_POINTER(aLink);
   *aLink = nullptr;
 
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     NS_IF_ADDREF(*aLink = ToXPC(Intl()->LinkAt(aIndex)));
@@ -767,14 +696,12 @@ xpcAccessibleHyperText::GetLinkAt(int32_t aIndex, nsIAccessibleHyperLink** aLink
 
 NS_IMETHODIMP
 xpcAccessibleHyperText::GetLinkIndex(nsIAccessibleHyperLink* aLink,
-                                     int32_t* aIndex)
-{
+                                     int32_t* aIndex) {
   NS_ENSURE_ARG_POINTER(aLink);
   NS_ENSURE_ARG_POINTER(aIndex);
   *aIndex = -1;
 
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   nsCOMPtr<nsIAccessible> xpcLink(do_QueryInterface(aLink));
   if (Accessible* accLink = xpcLink->ToInternalAccessible()) {
@@ -784,7 +711,7 @@ xpcAccessibleHyperText::GetLinkIndex(nsIAccessibleHyperLink* aLink,
     return NS_ERROR_NOT_IMPLEMENTED;
 #else
     xpcAccessibleHyperText* linkHyperText =
-      static_cast<xpcAccessibleHyperText*>(xpcLink.get());
+        static_cast<xpcAccessibleHyperText*>(xpcLink.get());
     ProxyAccessible* proxyLink = linkHyperText->mIntl.AsProxy();
     if (proxyLink) {
       *aIndex = mIntl.AsProxy()->LinkIndexOf(proxyLink);
@@ -797,13 +724,11 @@ xpcAccessibleHyperText::GetLinkIndex(nsIAccessibleHyperLink* aLink,
 
 NS_IMETHODIMP
 xpcAccessibleHyperText::GetLinkIndexAtOffset(int32_t aOffset,
-                                             int32_t* aLinkIndex)
-{
+                                             int32_t* aLinkIndex) {
   NS_ENSURE_ARG_POINTER(aLinkIndex);
-  *aLinkIndex = -1; // API says this magic value means 'not found'
+  *aLinkIndex = -1;  // API says this magic value means 'not found'
 
-  if (mIntl.IsNull())
-    return NS_ERROR_FAILURE;
+  if (mIntl.IsNull()) return NS_ERROR_FAILURE;
 
   if (mIntl.IsAccessible()) {
     *aLinkIndex = Intl()->LinkIndexAtOffset(aOffset);
