@@ -40,12 +40,10 @@ using namespace mozilla::a11y;
 // XULTreeAccessible
 ////////////////////////////////////////////////////////////////////////////////
 
-XULTreeAccessible::
-  XULTreeAccessible(nsIContent* aContent, DocAccessible* aDoc,
-                    nsTreeBodyFrame* aTreeFrame) :
-  AccessibleWrap(aContent, aDoc),
-  mAccessibleCache(kDefaultTreeCacheLength)
-{
+XULTreeAccessible::XULTreeAccessible(nsIContent* aContent, DocAccessible* aDoc,
+                                     nsTreeBodyFrame* aTreeFrame)
+    : AccessibleWrap(aContent, aDoc),
+      mAccessibleCache(kDefaultTreeCacheLength) {
   mType = eXULTreeType;
   mGenericTypes |= eSelect;
 
@@ -58,21 +56,18 @@ XULTreeAccessible::
   nsIContent* parentContent = mContent->GetParent();
   if (parentContent) {
     nsCOMPtr<nsIAutoCompletePopup> autoCompletePopupElm =
-      do_QueryInterface(parentContent);
-    if (autoCompletePopupElm)
-      mGenericTypes |= eAutoCompletePopup;
+        do_QueryInterface(parentContent);
+    if (autoCompletePopupElm) mGenericTypes |= eAutoCompletePopup;
   }
 }
 
-XULTreeAccessible::~XULTreeAccessible()
-{
-}
+XULTreeAccessible::~XULTreeAccessible() {}
 
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeAccessible: nsISupports and cycle collection implementation
 
-NS_IMPL_CYCLE_COLLECTION_INHERITED(XULTreeAccessible, Accessible,
-                                   mTree, mAccessibleCache)
+NS_IMPL_CYCLE_COLLECTION_INHERITED(XULTreeAccessible, Accessible, mTree,
+                                   mAccessibleCache)
 
 NS_INTERFACE_MAP_BEGIN_CYCLE_COLLECTION(XULTreeAccessible)
 NS_INTERFACE_MAP_END_INHERITING(Accessible)
@@ -83,9 +78,7 @@ NS_IMPL_RELEASE_INHERITED(XULTreeAccessible, Accessible)
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeAccessible: Accessible implementation
 
-uint64_t
-XULTreeAccessible::NativeState()
-{
+uint64_t XULTreeAccessible::NativeState() {
   // Get focus status from base class.
   uint64_t state = Accessible::NativeState();
 
@@ -93,8 +86,7 @@ XULTreeAccessible::NativeState()
   state |= states::READONLY;
 
   // multiselectable state.
-  if (!mTreeView)
-    return state;
+  if (!mTreeView) return state;
 
   nsCOMPtr<nsITreeSelection> selection;
   mTreeView->GetSelection(getter_AddRefs(selection));
@@ -104,24 +96,19 @@ XULTreeAccessible::NativeState()
   nsresult rv = selection->GetSingle(&isSingle);
   NS_ENSURE_SUCCESS(rv, state);
 
-  if (!isSingle)
-    state |= states::MULTISELECTABLE;
+  if (!isSingle) state |= states::MULTISELECTABLE;
 
   return state;
 }
 
-void
-XULTreeAccessible::Value(nsString& aValue)
-{
+void XULTreeAccessible::Value(nsString& aValue) {
   aValue.Truncate();
-  if (!mTreeView)
-    return;
+  if (!mTreeView) return;
 
   // Return the value is the first selected child.
   nsCOMPtr<nsITreeSelection> selection;
   mTreeView->GetSelection(getter_AddRefs(selection));
-  if (!selection)
-    return;
+  if (!selection) return;
 
   int32_t currentIndex;
   selection->GetCurrentIndex(&currentIndex);
@@ -130,20 +117,16 @@ XULTreeAccessible::Value(nsString& aValue)
 
     nsCOMPtr<nsITreeColumns> cols;
     mTree->GetColumns(getter_AddRefs(cols));
-    if (cols)
-      cols->GetKeyColumn(getter_AddRefs(keyCol));
+    if (cols) cols->GetKeyColumn(getter_AddRefs(keyCol));
 
     mTreeView->GetCellText(currentIndex, keyCol, aValue);
   }
-
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeAccessible: Accessible implementation
 
-void
-XULTreeAccessible::Shutdown()
-{
+void XULTreeAccessible::Shutdown() {
   if (mDoc && !mDoc->IsDefunct()) {
     UnbindCacheEntriesFromDocument(mAccessibleCache);
   }
@@ -154,18 +137,16 @@ XULTreeAccessible::Shutdown()
   AccessibleWrap::Shutdown();
 }
 
-role
-XULTreeAccessible::NativeRole()
-{
+role XULTreeAccessible::NativeRole() {
   // No primary column means we're in a list. In fact, history and mail turn off
   // the primary flag when switching to a flat view.
 
-  nsIContent* child = nsTreeUtils::GetDescendantChild(mContent, nsGkAtoms::treechildren);
+  nsIContent* child =
+      nsTreeUtils::GetDescendantChild(mContent, nsGkAtoms::treechildren);
   NS_ASSERTION(child, "tree without treechildren!");
   nsTreeBodyFrame* treeFrame = do_QueryFrame(child->GetPrimaryFrame());
   NS_ASSERTION(treeFrame, "xul tree accessible for tree without a frame!");
-  if (!treeFrame)
-    return roles::LIST;
+  if (!treeFrame) return roles::LIST;
 
   RefPtr<nsTreeColumns> cols = treeFrame->Columns();
   nsCOMPtr<nsITreeColumn> primaryCol;
@@ -177,18 +158,15 @@ XULTreeAccessible::NativeRole()
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeAccessible: Accessible implementation (DON'T put methods here)
 
-Accessible*
-XULTreeAccessible::ChildAtPoint(int32_t aX, int32_t aY,
-                                EWhichChildAtPoint aWhichChild)
-{
-  nsIFrame *frame = GetFrame();
-  if (!frame)
-    return nullptr;
+Accessible* XULTreeAccessible::ChildAtPoint(int32_t aX, int32_t aY,
+                                            EWhichChildAtPoint aWhichChild) {
+  nsIFrame* frame = GetFrame();
+  if (!frame) return nullptr;
 
-  nsPresContext *presContext = frame->PresContext();
+  nsPresContext* presContext = frame->PresContext();
   nsIPresShell* presShell = presContext->PresShell();
 
-  nsIFrame *rootFrame = presShell->GetRootFrame();
+  nsIFrame* rootFrame = presShell->GetRootFrame();
   NS_ENSURE_TRUE(rootFrame, nullptr);
 
   CSSIntRect rootRect = rootFrame->GetScreenRect();
@@ -213,8 +191,7 @@ XULTreeAccessible::ChildAtPoint(int32_t aX, int32_t aY,
     RefPtr<XULTreeItemAccessibleBase> treeitem = do_QueryObject(child);
 
     Accessible* cell = treeitem->GetCellAccessible(column);
-    if (cell)
-      child = cell;
+    if (cell) child = cell;
   }
 
   return child;
@@ -223,40 +200,30 @@ XULTreeAccessible::ChildAtPoint(int32_t aX, int32_t aY,
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeAccessible: SelectAccessible
 
-Accessible*
-XULTreeAccessible::CurrentItem()
-{
-  if (!mTreeView)
-    return nullptr;
+Accessible* XULTreeAccessible::CurrentItem() {
+  if (!mTreeView) return nullptr;
 
   nsCOMPtr<nsITreeSelection> selection;
   mTreeView->GetSelection(getter_AddRefs(selection));
   if (selection) {
     int32_t currentIndex = -1;
     selection->GetCurrentIndex(&currentIndex);
-    if (currentIndex >= 0)
-      return GetTreeItemAccessible(currentIndex);
+    if (currentIndex >= 0) return GetTreeItemAccessible(currentIndex);
   }
 
   return nullptr;
 }
 
-void
-XULTreeAccessible::SetCurrentItem(Accessible* aItem)
-{
+void XULTreeAccessible::SetCurrentItem(Accessible* aItem) {
   NS_ERROR("XULTreeAccessible::SetCurrentItem not implemented");
 }
 
-void
-XULTreeAccessible::SelectedItems(nsTArray<Accessible*>* aItems)
-{
-  if (!mTreeView)
-    return;
+void XULTreeAccessible::SelectedItems(nsTArray<Accessible*>* aItems) {
+  if (!mTreeView) return;
 
   nsCOMPtr<nsITreeSelection> selection;
   mTreeView->GetSelection(getter_AddRefs(selection));
-  if (!selection)
-    return;
+  if (!selection) return;
 
   int32_t rangeCount = 0;
   selection->GetRangeCount(&rangeCount);
@@ -265,17 +232,13 @@ XULTreeAccessible::SelectedItems(nsTArray<Accessible*>* aItems)
     selection->GetRangeAt(rangeIdx, &firstIdx, &lastIdx);
     for (int32_t rowIdx = firstIdx; rowIdx <= lastIdx; rowIdx++) {
       Accessible* item = GetTreeItemAccessible(rowIdx);
-      if (item)
-        aItems->AppendElement(item);
+      if (item) aItems->AppendElement(item);
     }
   }
 }
 
-uint32_t
-XULTreeAccessible::SelectedItemCount()
-{
-  if (!mTreeView)
-    return 0;
+uint32_t XULTreeAccessible::SelectedItemCount() {
+  if (!mTreeView) return 0;
 
   nsCOMPtr<nsITreeSelection> selection;
   mTreeView->GetSelection(getter_AddRefs(selection));
@@ -288,49 +251,38 @@ XULTreeAccessible::SelectedItemCount()
   return 0;
 }
 
-bool
-XULTreeAccessible::AddItemToSelection(uint32_t aIndex)
-{
-  if (!mTreeView)
-    return false;
+bool XULTreeAccessible::AddItemToSelection(uint32_t aIndex) {
+  if (!mTreeView) return false;
 
   nsCOMPtr<nsITreeSelection> selection;
   mTreeView->GetSelection(getter_AddRefs(selection));
   if (selection) {
     bool isSelected = false;
     selection->IsSelected(aIndex, &isSelected);
-    if (!isSelected)
-      selection->ToggleSelect(aIndex);
+    if (!isSelected) selection->ToggleSelect(aIndex);
 
     return true;
   }
   return false;
 }
 
-bool
-XULTreeAccessible::RemoveItemFromSelection(uint32_t aIndex)
-{
-  if (!mTreeView)
-    return false;
+bool XULTreeAccessible::RemoveItemFromSelection(uint32_t aIndex) {
+  if (!mTreeView) return false;
 
   nsCOMPtr<nsITreeSelection> selection;
   mTreeView->GetSelection(getter_AddRefs(selection));
   if (selection) {
     bool isSelected = false;
     selection->IsSelected(aIndex, &isSelected);
-    if (isSelected)
-      selection->ToggleSelect(aIndex);
+    if (isSelected) selection->ToggleSelect(aIndex);
 
     return true;
   }
   return false;
 }
 
-bool
-XULTreeAccessible::IsItemSelected(uint32_t aIndex)
-{
-  if (!mTreeView)
-    return false;
+bool XULTreeAccessible::IsItemSelected(uint32_t aIndex) {
+  if (!mTreeView) return false;
 
   nsCOMPtr<nsITreeSelection> selection;
   mTreeView->GetSelection(getter_AddRefs(selection));
@@ -342,31 +294,23 @@ XULTreeAccessible::IsItemSelected(uint32_t aIndex)
   return false;
 }
 
-bool
-XULTreeAccessible::UnselectAll()
-{
-  if (!mTreeView)
-    return false;
+bool XULTreeAccessible::UnselectAll() {
+  if (!mTreeView) return false;
 
   nsCOMPtr<nsITreeSelection> selection;
   mTreeView->GetSelection(getter_AddRefs(selection));
-  if (!selection)
-    return false;
+  if (!selection) return false;
 
   selection->ClearSelection();
   return true;
 }
 
-Accessible*
-XULTreeAccessible::GetSelectedItem(uint32_t aIndex)
-{
-  if (!mTreeView)
-    return nullptr;
+Accessible* XULTreeAccessible::GetSelectedItem(uint32_t aIndex) {
+  if (!mTreeView) return nullptr;
 
   nsCOMPtr<nsITreeSelection> selection;
   mTreeView->GetSelection(getter_AddRefs(selection));
-  if (!selection)
-    return nullptr;
+  if (!selection) return nullptr;
 
   uint32_t selCount = 0;
   int32_t rangeCount = 0;
@@ -375,8 +319,7 @@ XULTreeAccessible::GetSelectedItem(uint32_t aIndex)
     int32_t firstIdx = 0, lastIdx = -1;
     selection->GetRangeAt(rangeIdx, &firstIdx, &lastIdx);
     for (int32_t rowIdx = firstIdx; rowIdx <= lastIdx; rowIdx++) {
-      if (selCount == aIndex)
-        return GetTreeItemAccessible(rowIdx);
+      if (selCount == aIndex) return GetTreeItemAccessible(rowIdx);
 
       selCount++;
     }
@@ -385,12 +328,9 @@ XULTreeAccessible::GetSelectedItem(uint32_t aIndex)
   return nullptr;
 }
 
-bool
-XULTreeAccessible::SelectAll()
-{
+bool XULTreeAccessible::SelectAll() {
   // see if we are multiple select if so set ourselves as such
-  if (!mTreeView)
-    return false;
+  if (!mTreeView) return false;
 
   nsCOMPtr<nsITreeSelection> selection;
   mTreeView->GetSelection(getter_AddRefs(selection));
@@ -409,23 +349,17 @@ XULTreeAccessible::SelectAll()
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeAccessible: Accessible implementation
 
-Accessible*
-XULTreeAccessible::GetChildAt(uint32_t aIndex) const
-{
+Accessible* XULTreeAccessible::GetChildAt(uint32_t aIndex) const {
   uint32_t childCount = Accessible::ChildCount();
-  if (aIndex < childCount)
-    return Accessible::GetChildAt(aIndex);
+  if (aIndex < childCount) return Accessible::GetChildAt(aIndex);
 
   return GetTreeItemAccessible(aIndex - childCount);
 }
 
-uint32_t
-XULTreeAccessible::ChildCount() const
-{
+uint32_t XULTreeAccessible::ChildCount() const {
   // Tree's children count is row count + treecols count.
   uint32_t childCount = Accessible::ChildCount();
-  if (!mTreeView)
-    return childCount;
+  if (!mTreeView) return childCount;
 
   int32_t rowCount = 0;
   mTreeView->GetRowCount(&rowCount);
@@ -434,9 +368,7 @@ XULTreeAccessible::ChildCount() const
   return childCount;
 }
 
-Relation
-XULTreeAccessible::RelationByType(RelationType aType)
-{
+Relation XULTreeAccessible::RelationByType(RelationType aType) {
   if (aType == RelationType::NODE_PARENT_OF) {
     if (mTreeView)
       return Relation(new XULTreeItemIterator(this, mTreeView, -1));
@@ -450,18 +382,12 @@ XULTreeAccessible::RelationByType(RelationType aType)
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeAccessible: Widgets
 
-bool
-XULTreeAccessible::IsWidget() const
-{
-  return true;
-}
+bool XULTreeAccessible::IsWidget() const { return true; }
 
-bool
-XULTreeAccessible::IsActiveWidget() const
-{
+bool XULTreeAccessible::IsActiveWidget() const {
   if (IsAutoCompletePopup()) {
     nsCOMPtr<nsIAutoCompletePopup> autoCompletePopupElm =
-      do_QueryInterface(mContent->GetParent());
+        do_QueryInterface(mContent->GetParent());
 
     if (autoCompletePopupElm) {
       bool isOpen = false;
@@ -472,12 +398,10 @@ XULTreeAccessible::IsActiveWidget() const
   return FocusMgr()->HasDOMFocus(mContent);
 }
 
-bool
-XULTreeAccessible::AreItemsOperable() const
-{
+bool XULTreeAccessible::AreItemsOperable() const {
   if (IsAutoCompletePopup()) {
     nsCOMPtr<nsIAutoCompletePopup> autoCompletePopupElm =
-      do_QueryInterface(mContent->GetParent());
+        do_QueryInterface(mContent->GetParent());
 
     if (autoCompletePopupElm) {
       bool isOpen = false;
@@ -488,24 +412,21 @@ XULTreeAccessible::AreItemsOperable() const
   return true;
 }
 
-Accessible*
-XULTreeAccessible::ContainerWidget() const
-{
+Accessible* XULTreeAccessible::ContainerWidget() const {
   if (IsAutoCompletePopup()) {
     // This works for XUL autocompletes. It doesn't work for HTML forms
     // autocomplete because of potential crossprocess calls (when autocomplete
     // lives in content process while popup lives in chrome process). If that's
     // a problem then rethink Widgets interface.
     nsCOMPtr<nsIDOMXULMenuListElement> menuListElm =
-      do_QueryInterface(mContent->GetParent());
+        do_QueryInterface(mContent->GetParent());
     if (menuListElm) {
       nsCOMPtr<nsIDOMNode> inputElm;
       menuListElm->GetInputField(getter_AddRefs(inputElm));
       if (inputElm) {
         nsCOMPtr<nsINode> inputNode = do_QueryInterface(inputElm);
         if (inputNode) {
-          Accessible* input =
-            mDoc->GetAccessible(inputNode);
+          Accessible* input = mDoc->GetAccessible(inputNode);
           return input ? input->ContainerWidget() : nullptr;
         }
       }
@@ -517,21 +438,16 @@ XULTreeAccessible::ContainerWidget() const
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeAccessible: public implementation
 
-Accessible*
-XULTreeAccessible::GetTreeItemAccessible(int32_t aRow) const
-{
-  if (aRow < 0 || IsDefunct() || !mTreeView)
-    return nullptr;
+Accessible* XULTreeAccessible::GetTreeItemAccessible(int32_t aRow) const {
+  if (aRow < 0 || IsDefunct() || !mTreeView) return nullptr;
 
   int32_t rowCount = 0;
   nsresult rv = mTreeView->GetRowCount(&rowCount);
-  if (NS_FAILED(rv) || aRow >= rowCount)
-    return nullptr;
+  if (NS_FAILED(rv) || aRow >= rowCount) return nullptr;
 
-  void *key = reinterpret_cast<void*>(intptr_t(aRow));
+  void* key = reinterpret_cast<void*>(intptr_t(aRow));
   Accessible* cachedTreeItem = mAccessibleCache.GetWeak(key);
-  if (cachedTreeItem)
-    return cachedTreeItem;
+  if (cachedTreeItem) return cachedTreeItem;
 
   RefPtr<Accessible> treeItem = CreateTreeItemAccessible(aRow);
   if (treeItem) {
@@ -543,11 +459,8 @@ XULTreeAccessible::GetTreeItemAccessible(int32_t aRow) const
   return nullptr;
 }
 
-void
-XULTreeAccessible::InvalidateCache(int32_t aRow, int32_t aCount)
-{
-  if (IsDefunct())
-    return;
+void XULTreeAccessible::InvalidateCache(int32_t aRow, int32_t aCount) {
+  if (IsDefunct()) return;
 
   if (!mTreeView) {
     UnbindCacheEntriesFromDocument(mAccessibleCache);
@@ -555,20 +468,18 @@ XULTreeAccessible::InvalidateCache(int32_t aRow, int32_t aCount)
   }
 
   // Do not invalidate the cache if rows have been inserted.
-  if (aCount > 0)
-    return;
+  if (aCount > 0) return;
 
   DocAccessible* document = Document();
 
   // Fire destroy event for removed tree items and delete them from caches.
   for (int32_t rowIdx = aRow; rowIdx < aRow - aCount; rowIdx++) {
-
     void* key = reinterpret_cast<void*>(intptr_t(rowIdx));
     Accessible* treeItem = mAccessibleCache.GetWeak(key);
 
     if (treeItem) {
       RefPtr<AccEvent> event =
-        new AccEvent(nsIAccessibleEvent::EVENT_HIDE, treeItem);
+          new AccEvent(nsIAccessibleEvent::EVENT_HIDE, treeItem);
       nsEventShell::FireEvent(event);
 
       // Unbind from document, shutdown and remove from tree cache.
@@ -582,14 +493,12 @@ XULTreeAccessible::InvalidateCache(int32_t aRow, int32_t aCount)
   // items silently from caches.
   int32_t newRowCount = 0;
   nsresult rv = mTreeView->GetRowCount(&newRowCount);
-  if (NS_FAILED(rv))
-    return;
+  if (NS_FAILED(rv)) return;
 
   int32_t oldRowCount = newRowCount - aCount;
 
   for (int32_t rowIdx = newRowCount; rowIdx < oldRowCount; ++rowIdx) {
-
-    void *key = reinterpret_cast<void*>(intptr_t(rowIdx));
+    void* key = reinterpret_cast<void*>(intptr_t(rowIdx));
     Accessible* treeItem = mAccessibleCache.GetWeak(key);
 
     if (treeItem) {
@@ -600,12 +509,10 @@ XULTreeAccessible::InvalidateCache(int32_t aRow, int32_t aCount)
   }
 }
 
-void
-XULTreeAccessible::TreeViewInvalidated(int32_t aStartRow, int32_t aEndRow,
-                                       int32_t aStartCol, int32_t aEndCol)
-{
-  if (IsDefunct())
-    return;
+void XULTreeAccessible::TreeViewInvalidated(int32_t aStartRow, int32_t aEndRow,
+                                            int32_t aStartCol,
+                                            int32_t aEndCol) {
+  if (IsDefunct()) return;
 
   if (!mTreeView) {
     UnbindCacheEntriesFromDocument(mAccessibleCache);
@@ -618,35 +525,32 @@ XULTreeAccessible::TreeViewInvalidated(int32_t aStartRow, int32_t aEndRow,
   if (endRow == -1) {
     int32_t rowCount = 0;
     rv = mTreeView->GetRowCount(&rowCount);
-    if (NS_FAILED(rv))
-      return;
+    if (NS_FAILED(rv)) return;
 
     endRow = rowCount - 1;
   }
 
   nsCOMPtr<nsITreeColumns> treeColumns;
   mTree->GetColumns(getter_AddRefs(treeColumns));
-  if (!treeColumns)
-    return;
+  if (!treeColumns) return;
 
   int32_t endCol = aEndCol;
 
   if (endCol == -1) {
     int32_t colCount = 0;
     rv = treeColumns->GetCount(&colCount);
-    if (NS_FAILED(rv))
-      return;
+    if (NS_FAILED(rv)) return;
 
     endCol = colCount - 1;
   }
 
   for (int32_t rowIdx = aStartRow; rowIdx <= endRow; ++rowIdx) {
-
-    void *key = reinterpret_cast<void*>(intptr_t(rowIdx));
+    void* key = reinterpret_cast<void*>(intptr_t(rowIdx));
     Accessible* accessible = mAccessibleCache.GetWeak(key);
 
     if (accessible) {
-      RefPtr<XULTreeItemAccessibleBase> treeitemAcc = do_QueryObject(accessible);
+      RefPtr<XULTreeItemAccessibleBase> treeitemAcc =
+          do_QueryObject(accessible);
       NS_ASSERTION(treeitemAcc, "Wrong accessible at the given key!");
 
       treeitemAcc->RowInvalidated(aStartCol, endCol);
@@ -654,11 +558,8 @@ XULTreeAccessible::TreeViewInvalidated(int32_t aStartRow, int32_t aEndRow,
   }
 }
 
-void
-XULTreeAccessible::TreeViewChanged(nsITreeView* aView)
-{
-  if (IsDefunct())
-    return;
+void XULTreeAccessible::TreeViewChanged(nsITreeView* aView) {
+  if (IsDefunct()) return;
 
   // Fire reorder event on tree accessible on accessible tree (do not fire
   // show/hide events on tree items because it can be expensive to fire them for
@@ -679,12 +580,11 @@ XULTreeAccessible::TreeViewChanged(nsITreeView* aView)
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeAccessible: protected implementation
 
-already_AddRefed<Accessible>
-XULTreeAccessible::CreateTreeItemAccessible(int32_t aRow) const
-{
-  RefPtr<Accessible> accessible =
-    new XULTreeItemAccessible(mContent, mDoc, const_cast<XULTreeAccessible*>(this),
-                              mTree, mTreeView, aRow);
+already_AddRefed<Accessible> XULTreeAccessible::CreateTreeItemAccessible(
+    int32_t aRow) const {
+  RefPtr<Accessible> accessible = new XULTreeItemAccessible(
+      mContent, mDoc, const_cast<XULTreeAccessible*>(this), mTree, mTreeView,
+      aRow);
 
   return accessible.forget();
 }
@@ -693,26 +593,23 @@ XULTreeAccessible::CreateTreeItemAccessible(int32_t aRow) const
 // XULTreeItemAccessibleBase
 ////////////////////////////////////////////////////////////////////////////////
 
-XULTreeItemAccessibleBase::
-  XULTreeItemAccessibleBase(nsIContent* aContent, DocAccessible* aDoc,
-                            Accessible* aParent, nsITreeBoxObject* aTree,
-                            nsITreeView* aTreeView, int32_t aRow) :
-  AccessibleWrap(aContent, aDoc),
-  mTree(aTree), mTreeView(aTreeView), mRow(aRow)
-{
+XULTreeItemAccessibleBase::XULTreeItemAccessibleBase(
+    nsIContent* aContent, DocAccessible* aDoc, Accessible* aParent,
+    nsITreeBoxObject* aTree, nsITreeView* aTreeView, int32_t aRow)
+    : AccessibleWrap(aContent, aDoc),
+      mTree(aTree),
+      mTreeView(aTreeView),
+      mRow(aRow) {
   mParent = aParent;
   mStateFlags |= eSharedNode;
 }
 
-XULTreeItemAccessibleBase::~XULTreeItemAccessibleBase()
-{
-}
+XULTreeItemAccessibleBase::~XULTreeItemAccessibleBase() {}
 
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeItemAccessibleBase: nsISupports implementation
 
-NS_IMPL_CYCLE_COLLECTION_INHERITED(XULTreeItemAccessibleBase, Accessible,
-                                   mTree)
+NS_IMPL_CYCLE_COLLECTION_INHERITED(XULTreeItemAccessibleBase, Accessible, mTree)
 
 NS_IMPL_ISUPPORTS_CYCLE_COLLECTION_INHERITED(XULTreeItemAccessibleBase,
                                              Accessible,
@@ -721,29 +618,23 @@ NS_IMPL_ISUPPORTS_CYCLE_COLLECTION_INHERITED(XULTreeItemAccessibleBase,
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeItemAccessibleBase: Accessible
 
-Accessible*
-XULTreeItemAccessibleBase::FocusedChild()
-{
+Accessible* XULTreeItemAccessibleBase::FocusedChild() {
   return FocusMgr()->FocusedAccessible() == this ? this : nullptr;
 }
 
-nsIntRect
-XULTreeItemAccessibleBase::Bounds() const
-{
+nsIntRect XULTreeItemAccessibleBase::Bounds() const {
   // Get x coordinate and width from treechildren element, get y coordinate and
   // height from tree cell.
 
   nsCOMPtr<nsIBoxObject> boxObj = nsCoreUtils::GetTreeBodyBoxObject(mTree);
-  if (!boxObj)
-    return nsIntRect();
+  if (!boxObj) return nsIntRect();
 
   nsCOMPtr<nsITreeColumn> column = nsCoreUtils::GetFirstSensibleColumn(mTree);
 
   int32_t x = 0, y = 0, width = 0, height = 0;
-  nsresult rv = mTree->GetCoordsForCellItem(mRow, column, EmptyString(),
-                                            &x, &y, &width, &height);
-  if (NS_FAILED(rv))
-    return nsIntRect();
+  nsresult rv = mTree->GetCoordsForCellItem(mRow, column, EmptyString(), &x, &y,
+                                            &width, &height);
+  if (NS_FAILED(rv)) return nsIntRect();
 
   boxObj->GetWidth(&width);
 
@@ -761,43 +652,33 @@ XULTreeItemAccessibleBase::Bounds() const
                    presContext->CSSPixelsToDevPixels(height));
 }
 
-void
-XULTreeItemAccessibleBase::SetSelected(bool aSelect)
-{
+void XULTreeItemAccessibleBase::SetSelected(bool aSelect) {
   nsCOMPtr<nsITreeSelection> selection;
   mTreeView->GetSelection(getter_AddRefs(selection));
   if (selection) {
     bool isSelected = false;
     selection->IsSelected(mRow, &isSelected);
-    if (isSelected != aSelect)
-      selection->ToggleSelect(mRow);
+    if (isSelected != aSelect) selection->ToggleSelect(mRow);
   }
 }
 
-void
-XULTreeItemAccessibleBase::TakeFocus()
-{
+void XULTreeItemAccessibleBase::TakeFocus() {
   nsCOMPtr<nsITreeSelection> selection;
   mTreeView->GetSelection(getter_AddRefs(selection));
-  if (selection)
-    selection->SetCurrentIndex(mRow);
+  if (selection) selection->SetCurrentIndex(mRow);
 
   // focus event will be fired here
   Accessible::TakeFocus();
 }
 
-Relation
-XULTreeItemAccessibleBase::RelationByType(RelationType aType)
-{
-
+Relation XULTreeItemAccessibleBase::RelationByType(RelationType aType) {
   switch (aType) {
     case RelationType::NODE_CHILD_OF: {
       int32_t parentIndex = -1;
       if (!NS_SUCCEEDED(mTreeView->GetParentIndex(mRow, &parentIndex)))
         return Relation();
 
-      if (parentIndex == -1)
-        return Relation(mParent);
+      if (parentIndex == -1) return Relation(mParent);
 
       XULTreeAccessible* treeAcc = mParent->AsXULTree();
       return Relation(treeAcc->GetTreeItemAccessible(parentIndex));
@@ -820,17 +701,13 @@ XULTreeItemAccessibleBase::RelationByType(RelationType aType)
   }
 }
 
-uint8_t
-XULTreeItemAccessibleBase::ActionCount()
-{
+uint8_t XULTreeItemAccessibleBase::ActionCount() {
   // "activate" action is available for all treeitems, "expand/collapse" action
   // is avaible for treeitem which is container.
   return IsExpandable() ? 2 : 1;
 }
 
-void
-XULTreeItemAccessibleBase::ActionNameAt(uint8_t aIndex, nsAString& aName)
-{
+void XULTreeItemAccessibleBase::ActionNameAt(uint8_t aIndex, nsAString& aName) {
   if (aIndex == eAction_Click) {
     aName.AssignLiteral("activate");
     return;
@@ -846,11 +723,8 @@ XULTreeItemAccessibleBase::ActionNameAt(uint8_t aIndex, nsAString& aName)
   }
 }
 
-bool
-XULTreeItemAccessibleBase::DoAction(uint8_t aIndex)
-{
-  if (aIndex != eAction_Click &&
-      (aIndex != eAction_Expand || !IsExpandable()))
+bool XULTreeItemAccessibleBase::DoAction(uint8_t aIndex) {
+  if (aIndex != eAction_Click && (aIndex != eAction_Expand || !IsExpandable()))
     return false;
 
   DoCommand(nullptr, aIndex);
@@ -860,20 +734,16 @@ XULTreeItemAccessibleBase::DoAction(uint8_t aIndex)
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeItemAccessibleBase: Accessible implementation
 
-void
-XULTreeItemAccessibleBase::Shutdown()
-{
+void XULTreeItemAccessibleBase::Shutdown() {
   mTree = nullptr;
   mTreeView = nullptr;
   mRow = -1;
-  mParent = nullptr; // null-out to prevent base class's shutdown ops
+  mParent = nullptr;  // null-out to prevent base class's shutdown ops
 
   AccessibleWrap::Shutdown();
 }
 
-GroupPos
-XULTreeItemAccessibleBase::GroupPosition()
-{
+GroupPos XULTreeItemAccessibleBase::GroupPosition() {
   GroupPos groupPos;
 
   int32_t level;
@@ -884,11 +754,9 @@ XULTreeItemAccessibleBase::GroupPosition()
   for (int32_t index = mRow - 1; index >= 0; index--) {
     int32_t lvl = -1;
     if (NS_SUCCEEDED(mTreeView->GetLevel(index, &lvl))) {
-      if (lvl < level)
-        break;
+      if (lvl < level) break;
 
-      if (lvl == level)
-        topCount++;
+      if (lvl == level) topCount++;
     }
   }
 
@@ -900,11 +768,9 @@ XULTreeItemAccessibleBase::GroupPosition()
   for (int32_t index = mRow + 1; index < rowCount; index++) {
     int32_t lvl = -1;
     if (NS_SUCCEEDED(mTreeView->GetLevel(index, &lvl))) {
-      if (lvl < level)
-        break;
+      if (lvl < level) break;
 
-      if (lvl == level)
-        bottomCount++;
+      if (lvl == level) bottomCount++;
     }
   }
 
@@ -915,10 +781,7 @@ XULTreeItemAccessibleBase::GroupPosition()
   return groupPos;
 }
 
-uint64_t
-XULTreeItemAccessibleBase::NativeState()
-{
-
+uint64_t XULTreeItemAccessibleBase::NativeState() {
   // focusable and selectable states
   uint64_t state = NativeInteractiveState();
 
@@ -935,13 +798,11 @@ XULTreeItemAccessibleBase::NativeState()
   if (selection) {
     bool isSelected;
     selection->IsSelected(mRow, &isSelected);
-    if (isSelected)
-      state |= states::SELECTED;
+    if (isSelected) state |= states::SELECTED;
   }
 
   // focused state
-  if (FocusMgr()->IsFocused(this))
-    state |= states::FOCUSED;
+  if (FocusMgr()->IsFocused(this)) state |= states::FOCUSED;
 
   // invisible state
   int32_t firstVisibleRow, lastVisibleRow;
@@ -953,41 +814,31 @@ XULTreeItemAccessibleBase::NativeState()
   return state;
 }
 
-uint64_t
-XULTreeItemAccessibleBase::NativeInteractiveState() const
-{
+uint64_t XULTreeItemAccessibleBase::NativeInteractiveState() const {
   return states::FOCUSABLE | states::SELECTABLE;
 }
 
-int32_t
-XULTreeItemAccessibleBase::IndexInParent() const
-{
+int32_t XULTreeItemAccessibleBase::IndexInParent() const {
   return mParent ? mParent->ContentChildCount() + mRow : -1;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeItemAccessibleBase: Widgets
 
-Accessible*
-XULTreeItemAccessibleBase::ContainerWidget() const
-{
+Accessible* XULTreeItemAccessibleBase::ContainerWidget() const {
   return mParent;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeItemAccessibleBase: Accessible protected methods
 
-void
-XULTreeItemAccessibleBase::DispatchClickEvent(nsIContent* aContent,
-                                              uint32_t aActionIndex)
-{
-  if (IsDefunct())
-    return;
+void XULTreeItemAccessibleBase::DispatchClickEvent(nsIContent* aContent,
+                                                   uint32_t aActionIndex) {
+  if (IsDefunct()) return;
 
   nsCOMPtr<nsITreeColumns> columns;
   mTree->GetColumns(getter_AddRefs(columns));
-  if (!columns)
-    return;
+  if (!columns) return;
 
   // Get column and pseudo element.
   nsCOMPtr<nsITreeColumn> column;
@@ -1002,16 +853,12 @@ XULTreeItemAccessibleBase::DispatchClickEvent(nsIContent* aContent,
     pseudoElm = NS_LITERAL_STRING("twisty");
   }
 
-  if (column)
-    nsCoreUtils::DispatchClickEvent(mTree, mRow, column, pseudoElm);
+  if (column) nsCoreUtils::DispatchClickEvent(mTree, mRow, column, pseudoElm);
 }
 
-Accessible*
-XULTreeItemAccessibleBase::GetSiblingAtOffset(int32_t aOffset,
-                                              nsresult* aError) const
-{
-  if (aError)
-    *aError = NS_OK; // fail peacefully
+Accessible* XULTreeItemAccessibleBase::GetSiblingAtOffset(
+    int32_t aOffset, nsresult* aError) const {
+  if (aError) *aError = NS_OK;  // fail peacefully
 
   return mParent->GetChildAt(IndexInParent() + aOffset);
 }
@@ -1019,10 +866,7 @@ XULTreeItemAccessibleBase::GetSiblingAtOffset(int32_t aOffset,
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeItemAccessibleBase: protected implementation
 
-bool
-XULTreeItemAccessibleBase::IsExpandable()
-{
-
+bool XULTreeItemAccessibleBase::IsExpandable() {
   bool isContainer = false;
   mTreeView->IsContainer(mRow, &isContainer);
   if (isContainer) {
@@ -1034,8 +878,7 @@ XULTreeItemAccessibleBase::IsExpandable()
       nsCOMPtr<nsITreeColumn> primaryColumn;
       if (columns) {
         columns->GetPrimaryColumn(getter_AddRefs(primaryColumn));
-        if (primaryColumn &&
-            !nsCoreUtils::IsColumnHidden(primaryColumn))
+        if (primaryColumn && !nsCoreUtils::IsColumnHidden(primaryColumn))
           return true;
       }
     }
@@ -1044,10 +887,8 @@ XULTreeItemAccessibleBase::IsExpandable()
   return false;
 }
 
-void
-XULTreeItemAccessibleBase::GetCellName(nsITreeColumn* aColumn, nsAString& aName)
-{
-
+void XULTreeItemAccessibleBase::GetCellName(nsITreeColumn* aColumn,
+                                            nsAString& aName) {
   mTreeView->GetCellText(mRow, aColumn, aName);
 
   // If there is still no name try the cell value:
@@ -1056,36 +897,30 @@ XULTreeItemAccessibleBase::GetCellName(nsITreeColumn* aColumn, nsAString& aName)
   // where there is something shown in the cell (non-text) such as a star icon;
   // in which case GetCellValue for that cell would return "starred" or
   // "flagged" for example.
-  if (aName.IsEmpty())
-    mTreeView->GetCellValue(mRow, aColumn, aName);
+  if (aName.IsEmpty()) mTreeView->GetCellValue(mRow, aColumn, aName);
 }
 
-
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeItemAccessible
 ////////////////////////////////////////////////////////////////////////////////
 
-XULTreeItemAccessible::
-  XULTreeItemAccessible(nsIContent* aContent, DocAccessible* aDoc,
-                        Accessible* aParent, nsITreeBoxObject* aTree,
-                        nsITreeView* aTreeView, int32_t aRow) :
-  XULTreeItemAccessibleBase(aContent, aDoc, aParent, aTree, aTreeView, aRow)
-{
+XULTreeItemAccessible::XULTreeItemAccessible(
+    nsIContent* aContent, DocAccessible* aDoc, Accessible* aParent,
+    nsITreeBoxObject* aTree, nsITreeView* aTreeView, int32_t aRow)
+    : XULTreeItemAccessibleBase(aContent, aDoc, aParent, aTree, aTreeView,
+                                aRow) {
   mStateFlags |= eNoKidsFromDOM;
   mColumn = nsCoreUtils::GetFirstSensibleColumn(mTree);
   GetCellName(mColumn, mCachedName);
 }
 
-XULTreeItemAccessible::~XULTreeItemAccessible()
-{
-}
+XULTreeItemAccessible::~XULTreeItemAccessible() {}
 
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeItemAccessible: nsISupports implementation
 
 NS_IMPL_CYCLE_COLLECTION_INHERITED(XULTreeItemAccessible,
-                                   XULTreeItemAccessibleBase,
-                                   mColumn)
+                                   XULTreeItemAccessibleBase, mColumn)
 
 NS_INTERFACE_MAP_BEGIN_CYCLE_COLLECTION(XULTreeItemAccessible)
 NS_INTERFACE_MAP_END_INHERITING(XULTreeItemAccessibleBase)
@@ -1095,9 +930,7 @@ NS_IMPL_RELEASE_INHERITED(XULTreeItemAccessible, XULTreeItemAccessibleBase)
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeItemAccessible: nsIAccessible implementation
 
-ENameValueFlag
-XULTreeItemAccessible::Name(nsString& aName)
-{
+ENameValueFlag XULTreeItemAccessible::Name(nsString& aName) {
   aName.Truncate();
 
   GetCellName(mColumn, aName);
@@ -1107,16 +940,12 @@ XULTreeItemAccessible::Name(nsString& aName)
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeItemAccessible: Accessible implementation
 
-void
-XULTreeItemAccessible::Shutdown()
-{
+void XULTreeItemAccessible::Shutdown() {
   mColumn = nullptr;
   XULTreeItemAccessibleBase::Shutdown();
 }
 
-role
-XULTreeItemAccessible::NativeRole()
-{
+role XULTreeItemAccessible::NativeRole() {
   nsCOMPtr<nsITreeColumns> columns;
   mTree->GetColumns(getter_AddRefs(columns));
   if (!columns) {
@@ -1133,9 +962,8 @@ XULTreeItemAccessible::NativeRole()
 ////////////////////////////////////////////////////////////////////////////////
 // XULTreeItemAccessible: XULTreeItemAccessibleBase implementation
 
-void
-XULTreeItemAccessible::RowInvalidated(int32_t aStartColIdx, int32_t aEndColIdx)
-{
+void XULTreeItemAccessible::RowInvalidated(int32_t aStartColIdx,
+                                           int32_t aEndColIdx) {
   nsAutoString name;
   Name(name);
 
@@ -1145,26 +973,20 @@ XULTreeItemAccessible::RowInvalidated(int32_t aStartColIdx, int32_t aEndColIdx)
   }
 }
 
-
 ////////////////////////////////////////////////////////////////////////////////
 //  XULTreeColumAccessible
 ////////////////////////////////////////////////////////////////////////////////
 
-XULTreeColumAccessible::
-  XULTreeColumAccessible(nsIContent* aContent, DocAccessible* aDoc) :
-  XULColumAccessible(aContent, aDoc)
-{
-}
+XULTreeColumAccessible::XULTreeColumAccessible(nsIContent* aContent,
+                                               DocAccessible* aDoc)
+    : XULColumAccessible(aContent, aDoc) {}
 
-Accessible*
-XULTreeColumAccessible::GetSiblingAtOffset(int32_t aOffset,
-                                           nsresult* aError) const
-{
+Accessible* XULTreeColumAccessible::GetSiblingAtOffset(int32_t aOffset,
+                                                       nsresult* aError) const {
   if (aOffset < 0)
     return XULColumAccessible::GetSiblingAtOffset(aOffset, aError);
 
-  if (aError)
-    *aError =  NS_OK; // fail peacefully
+  if (aError) *aError = NS_OK;  // fail peacefully
 
   nsCOMPtr<nsITreeBoxObject> tree = nsCoreUtils::GetTreeBoxObject(mContent);
   if (tree) {
@@ -1176,8 +998,7 @@ XULTreeColumAccessible::GetSiblingAtOffset(int32_t aOffset,
       if (rowCount > 0 && aOffset <= rowCount) {
         XULTreeAccessible* treeAcc = Parent()->AsXULTree();
 
-        if (treeAcc)
-          return treeAcc->GetTreeItemAccessible(aOffset - 1);
+        if (treeAcc) return treeAcc->GetTreeItemAccessible(aOffset - 1);
       }
     }
   }
