@@ -46,7 +46,7 @@ void nsMAPIConfiguration::OpenConfiguration()
 }
 
 int16_t nsMAPIConfiguration::RegisterSession(uint32_t aHwnd,
-                const char16_t *aUserName, const char16_t *aPassword,
+                const nsCString& aUserName, const nsCString& aPassword,
                 bool aForceDownLoad, bool aNewSession,
                 uint32_t *aSession, const char *aIdKey)
 {
@@ -63,8 +63,8 @@ int16_t nsMAPIConfiguration::RegisterSession(uint32_t aHwnd,
     return -1;
   }
 
-  if (aUserName != nullptr && aUserName[0] != '\0')
-    m_ProfileMap.Get(nsDependentString(aUserName), &n_SessionId);
+  if (!aUserName.IsEmpty())
+    m_ProfileMap.Get(aUserName, &n_SessionId);
 
   // try to share a session; if not create a session
   if (n_SessionId > 0)
@@ -82,8 +82,7 @@ int16_t nsMAPIConfiguration::RegisterSession(uint32_t aHwnd,
   {
     // create a new session; if new session is specified OR there is no session
     nsMAPISession *pTemp = nullptr;
-    pTemp = new nsMAPISession(aHwnd, aUserName,
-                           aPassword, aForceDownLoad, aIdKey);
+    pTemp = new nsMAPISession(aHwnd, aUserName, aPassword, aForceDownLoad, aIdKey);
 
     if (pTemp != nullptr)
     {
@@ -95,8 +94,8 @@ int16_t nsMAPIConfiguration::RegisterSession(uint32_t aHwnd,
       if (session_generator == 0)
           session_generator++;
       m_SessionMap.Put(session_generator, pTemp);
-      if (aUserName != nullptr && aUserName[0] != '\0')
-        m_ProfileMap.Put(nsDependentString(aUserName), session_generator);
+      if (!aUserName.IsEmpty())
+        m_ProfileMap.Put(aUserName, session_generator);
       *aSession = session_generator;
       sessionCount++;
       nResult = 1;
@@ -266,15 +265,14 @@ HRESULT nsMAPIConfiguration::GetMAPIErrorFromNSError (nsresult res)
 }
 
 
-nsMAPISession::nsMAPISession(uint32_t aHwnd, const char16_t *aUserName,
-                             const char16_t *aPassword,
+nsMAPISession::nsMAPISession(uint32_t aHwnd, const nsCString& aUserName, const nsCString& aPassword,
                              bool aForceDownLoad, const char *aKey)
 : m_nShared(1),
   m_pIdKey(aKey)
 {
   m_listContext = NULL;
-  m_pProfileName.Assign(aUserName);
-  m_pPassword.Assign(aPassword);
+  m_pProfileName = aUserName;
+  m_pPassword = aPassword;
 }
 
 nsMAPISession::~nsMAPISession()
