@@ -15,7 +15,6 @@
 
 #include "gtest/gtest.h"
 
-
 #if defined(DEBUG) && !defined(XP_WIN) && !defined(ANDROID)
 #define HAS_GDB_SLEEP_DURATION 1
 extern unsigned int _gdb_sleep_duration;
@@ -23,10 +22,9 @@ extern unsigned int _gdb_sleep_duration;
 
 // Death tests are too slow on OSX because of the system crash reporter.
 #ifndef XP_DARWIN
-static void DisableCrashReporter()
-{
+static void DisableCrashReporter() {
   nsCOMPtr<nsICrashReporter> crashreporter =
-    do_GetService("@mozilla.org/toolkit/crash-reporter;1");
+      do_GetService("@mozilla.org/toolkit/crash-reporter;1");
   if (crashreporter) {
     crashreporter->SetEnabled(false);
   }
@@ -36,45 +34,44 @@ static void DisableCrashReporter()
 // when entering the subprocess, so that the expected crashes don't
 // create a minidump that the gtest harness will interpret as an error.
 #define ASSERT_DEATH_WRAP(a, b) \
-  ASSERT_DEATH_IF_SUPPORTED({ DisableCrashReporter(); a; }, b)
+  ASSERT_DEATH_IF_SUPPORTED(    \
+      {                         \
+        DisableCrashReporter(); \
+        a;                      \
+      },                        \
+      b)
 #else
 #define ASSERT_DEATH_WRAP(a, b)
 #endif
 
-
 using namespace mozilla;
 
-static inline void
-TestOne(size_t size)
-{
+static inline void TestOne(size_t size) {
   size_t req = size;
   size_t adv = malloc_good_size(req);
   char* p = (char*)malloc(req);
   size_t usable = moz_malloc_usable_size(p);
   // NB: Using EXPECT here so that we still free the memory on failure.
-  EXPECT_EQ(adv, usable) <<
-         "malloc_good_size(" << req << ") --> " << adv << "; "
-         "malloc_usable_size(" << req << ") --> " << usable;
+  EXPECT_EQ(adv, usable) << "malloc_good_size(" << req << ") --> " << adv
+                         << "; "
+                            "malloc_usable_size("
+                         << req << ") --> " << usable;
   free(p);
 }
 
-static inline void
-TestThree(size_t size)
-{
+static inline void TestThree(size_t size) {
   ASSERT_NO_FATAL_FAILURE(TestOne(size - 1));
   ASSERT_NO_FATAL_FAILURE(TestOne(size));
   ASSERT_NO_FATAL_FAILURE(TestOne(size + 1));
 }
 
-TEST(Jemalloc, UsableSizeInAdvance)
-{
+TEST(Jemalloc, UsableSizeInAdvance) {
   /*
    * Test every size up to a certain point, then (N-1, N, N+1) triplets for a
    * various sizes beyond that.
    */
 
-  for (size_t n = 0; n < 16_KiB; n++)
-    ASSERT_NO_FATAL_FAILURE(TestOne(n));
+  for (size_t n = 0; n < 16_KiB; n++) ASSERT_NO_FATAL_FAILURE(TestOne(n));
 
   for (size_t n = 16_KiB; n < 1_MiB; n += 4_KiB)
     ASSERT_NO_FATAL_FAILURE(TestThree(n));
@@ -86,13 +83,12 @@ TEST(Jemalloc, UsableSizeInAdvance)
 static int gStaticVar;
 
 bool InfoEq(jemalloc_ptr_info_t& aInfo, PtrInfoTag aTag, void* aAddr,
-            size_t aSize)
-{
+            size_t aSize) {
   return aInfo.tag == aTag && aInfo.addr == aAddr && aInfo.size == aSize;
 }
 
-bool InfoEqFreedPage(jemalloc_ptr_info_t& aInfo, void* aAddr, size_t aPageSize)
-{
+bool InfoEqFreedPage(jemalloc_ptr_info_t& aInfo, void* aAddr,
+                     size_t aPageSize) {
   size_t pageSizeMask = aPageSize - 1;
 
   return jemalloc_ptr_is_freed_page(&aInfo) &&
@@ -100,8 +96,7 @@ bool InfoEqFreedPage(jemalloc_ptr_info_t& aInfo, void* aAddr, size_t aPageSize)
          aInfo.size == aPageSize;
 }
 
-TEST(Jemalloc, PtrInfo)
-{
+TEST(Jemalloc, PtrInfo) {
   // Some things might be running in other threads, so ensure our assumptions
   // (e.g. about isFreedSmall and isFreedPage ratios below) are not altered by
   // other threads.
@@ -254,11 +249,10 @@ TEST(Jemalloc, PtrInfo)
   jemalloc_thread_local_arena(false);
 }
 
-size_t sSizes[] = { 1,      42,      79,      918,     1.5_KiB,
-                    73_KiB, 129_KiB, 1.1_MiB, 2.6_MiB, 5.1_MiB };
+size_t sSizes[] = {1,      42,      79,      918,     1.5_KiB,
+                   73_KiB, 129_KiB, 1.1_MiB, 2.6_MiB, 5.1_MiB};
 
-TEST(Jemalloc, Arenas)
-{
+TEST(Jemalloc, Arenas) {
   arena_id_t arena = moz_create_arena();
   ASSERT_TRUE(arena != 0);
   void* ptr = moz_arena_malloc(arena, 42);
@@ -290,7 +284,8 @@ TEST(Jemalloc, Arenas)
   (void)arena2;
 
   // For convenience, realloc can also be used to reallocate arena pointers.
-  // The result should be in the same arena. Test various size class transitions.
+  // The result should be in the same arena. Test various size class
+  // transitions.
   for (size_t from_size : sSizes) {
     SCOPED_TRACE(testing::Message() << "from_size = " << from_size);
     for (size_t to_size : sSizes) {
@@ -306,10 +301,10 @@ TEST(Jemalloc, Arenas)
     }
   }
 
-  // Until Bug 1364359 is fixed it is unsafe to call moz_dispose_arena.
-  // moz_dispose_arena(arena2);
-  // Until Bug 1364359 is fixed it is unsafe to call moz_dispose_arena.
-  // moz_dispose_arena(arena);
+    // Until Bug 1364359 is fixed it is unsafe to call moz_dispose_arena.
+    // moz_dispose_arena(arena2);
+    // Until Bug 1364359 is fixed it is unsafe to call moz_dispose_arena.
+    // moz_dispose_arena(arena);
 
 #ifdef HAS_GDB_SLEEP_DURATION
   _gdb_sleep_duration = old_gdb_sleep_duration;
@@ -320,13 +315,8 @@ TEST(Jemalloc, Arenas)
 // aOffset to aSize. For faster comparison, the caller is required to fill a
 // reference buffer with the wanted character, and give the size of that
 // reference buffer.
-static void
-bulk_compare(char* aPtr,
-             size_t aOffset,
-             size_t aSize,
-             char* aReference,
-             size_t aReferenceSize)
-{
+static void bulk_compare(char* aPtr, size_t aOffset, size_t aSize,
+                         char* aReference, size_t aReferenceSize) {
   for (size_t i = aOffset; i < aSize; i += aReferenceSize) {
     size_t length = std::min(aSize - i, aReferenceSize);
     if (memcmp(aPtr + i, aReference, length)) {
@@ -339,56 +329,44 @@ bulk_compare(char* aPtr,
 }
 
 // A range iterator for size classes between two given values.
-class SizeClassesBetween
-{
-public:
-  SizeClassesBetween(size_t aStart, size_t aEnd)
-    : mStart(aStart)
-    , mEnd(aEnd)
-  {
-  }
+class SizeClassesBetween {
+ public:
+  SizeClassesBetween(size_t aStart, size_t aEnd) : mStart(aStart), mEnd(aEnd) {}
 
-  class Iterator
-  {
-  public:
-    explicit Iterator(size_t aValue)
-      : mValue(malloc_good_size(aValue))
-    {
-    }
+  class Iterator {
+   public:
+    explicit Iterator(size_t aValue) : mValue(malloc_good_size(aValue)) {}
 
     operator size_t() const { return mValue; }
     size_t operator*() const { return mValue; }
-    Iterator& operator++()
-    {
+    Iterator& operator++() {
       mValue = malloc_good_size(mValue + 1);
       return *this;
     }
 
-  private:
+   private:
     size_t mValue;
   };
 
   Iterator begin() { return Iterator(mStart); }
   Iterator end() { return Iterator(mEnd); }
 
-private:
+ private:
   size_t mStart, mEnd;
 };
 
-#define ALIGNMENT_CEILING(s, alignment)                                        \
+#define ALIGNMENT_CEILING(s, alignment) \
   (((s) + (alignment - 1)) & (~(alignment - 1)))
 
-static bool
-IsSameRoundedHugeClass(size_t aSize1, size_t aSize2, jemalloc_stats_t& aStats)
-{
+static bool IsSameRoundedHugeClass(size_t aSize1, size_t aSize2,
+                                   jemalloc_stats_t& aStats) {
   return (aSize1 > aStats.large_max && aSize2 > aStats.large_max &&
           ALIGNMENT_CEILING(aSize1, aStats.chunksize) ==
-            ALIGNMENT_CEILING(aSize2, aStats.chunksize));
+              ALIGNMENT_CEILING(aSize2, aStats.chunksize));
 }
 
-static bool
-CanReallocInPlace(size_t aFromSize, size_t aToSize, jemalloc_stats_t& aStats)
-{
+static bool CanReallocInPlace(size_t aFromSize, size_t aToSize,
+                              jemalloc_stats_t& aStats) {
   if (aFromSize == malloc_good_size(aToSize)) {
     // Same size class: in-place.
     return true;
@@ -406,8 +384,7 @@ CanReallocInPlace(size_t aFromSize, size_t aToSize, jemalloc_stats_t& aStats)
   return false;
 }
 
-TEST(Jemalloc, InPlace)
-{
+TEST(Jemalloc, InPlace) {
   jemalloc_stats_t stats;
   jemalloc_stats(&stats);
 
@@ -436,8 +413,7 @@ TEST(Jemalloc, InPlace)
   // moz_dispose_arena(arena);
 }
 
-TEST(Jemalloc, JunkPoison)
-{
+TEST(Jemalloc, JunkPoison) {
   jemalloc_stats_t stats;
   jemalloc_stats(&stats);
 
@@ -476,13 +452,13 @@ TEST(Jemalloc, JunkPoison)
       size_t allocated = moz_malloc_usable_size(buf);
       if (stats.opt_junk || stats.opt_zero) {
         ASSERT_NO_FATAL_FAILURE(
-          bulk_compare(buf, 0, allocated, junk_buf, stats.page_size));
+            bulk_compare(buf, 0, allocated, junk_buf, stats.page_size));
       }
       moz_arena_free(arena, buf);
       // We purposefully do a use-after-free here, to check that the data was
       // poisoned.
       ASSERT_NO_FATAL_FAILURE(
-        bulk_compare(buf, 0, allocated, poison_buf, stats.page_size));
+          bulk_compare(buf, 0, allocated, poison_buf, stats.page_size));
     }
   }
 
@@ -497,9 +473,9 @@ TEST(Jemalloc, JunkPoison)
     char* ptr2 = (char*)moz_arena_realloc(arena, ptr, prev + 1);
     ASSERT_EQ(ptr, ptr2);
     ASSERT_NO_FATAL_FAILURE(
-      bulk_compare(ptr, 0, prev + 1, fill_buf, stats.page_size));
+        bulk_compare(ptr, 0, prev + 1, fill_buf, stats.page_size));
     ASSERT_NO_FATAL_FAILURE(
-      bulk_compare(ptr, prev + 1, size, poison_buf, stats.page_size));
+        bulk_compare(ptr, prev + 1, size, poison_buf, stats.page_size));
     moz_arena_free(arena, ptr);
     prev = size;
   }
@@ -517,27 +493,27 @@ TEST(Jemalloc, JunkPoison)
         ASSERT_EQ(ptr, ptr2);
         if (from_size >= to_size) {
           ASSERT_NO_FATAL_FAILURE(
-            bulk_compare(ptr, 0, to_size, fill_buf, stats.page_size));
+              bulk_compare(ptr, 0, to_size, fill_buf, stats.page_size));
           // On Windows (MALLOC_DECOMMIT), in-place realloc of huge allocations
           // decommits extra pages, writing to them becomes an error.
 #ifdef XP_WIN
           if (to_size > stats.large_max) {
             size_t page_limit = ALIGNMENT_CEILING(to_size, stats.page_size);
-            ASSERT_NO_FATAL_FAILURE(bulk_compare(
-              ptr, to_size, page_limit, poison_buf, stats.page_size));
+            ASSERT_NO_FATAL_FAILURE(bulk_compare(ptr, to_size, page_limit,
+                                                 poison_buf, stats.page_size));
             ASSERT_DEATH_WRAP(ptr[page_limit] = 0, "");
           } else
 #endif
           {
-            ASSERT_NO_FATAL_FAILURE(bulk_compare(
-              ptr, to_size, from_size, poison_buf, stats.page_size));
+            ASSERT_NO_FATAL_FAILURE(bulk_compare(ptr, to_size, from_size,
+                                                 poison_buf, stats.page_size));
           }
         } else {
           ASSERT_NO_FATAL_FAILURE(
-            bulk_compare(ptr, 0, from_size, fill_buf, stats.page_size));
+              bulk_compare(ptr, 0, from_size, fill_buf, stats.page_size));
           if (stats.opt_junk || stats.opt_zero) {
-            ASSERT_NO_FATAL_FAILURE(
-              bulk_compare(ptr, from_size, to_size, junk_buf, stats.page_size));
+            ASSERT_NO_FATAL_FAILURE(bulk_compare(ptr, from_size, to_size,
+                                                 junk_buf, stats.page_size));
           }
         }
         moz_arena_free(arena, ptr2);
@@ -568,15 +544,15 @@ TEST(Jemalloc, JunkPoison)
         ASSERT_NE(ptr, ptr2);
         if (from_size <= stats.large_max) {
           ASSERT_NO_FATAL_FAILURE(
-            bulk_compare(ptr, 0, from_size, poison_buf, stats.page_size));
+              bulk_compare(ptr, 0, from_size, poison_buf, stats.page_size));
         }
         ASSERT_NO_FATAL_FAILURE(
-          bulk_compare(ptr2, 0, from_size, fill_buf, stats.page_size));
+            bulk_compare(ptr2, 0, from_size, fill_buf, stats.page_size));
         if (stats.opt_junk || stats.opt_zero) {
           size_t rounded_to_size = malloc_good_size(to_size);
           ASSERT_NE(to_size, rounded_to_size);
-          ASSERT_NO_FATAL_FAILURE(bulk_compare(
-            ptr2, from_size, rounded_to_size, junk_buf, stats.page_size));
+          ASSERT_NO_FATAL_FAILURE(bulk_compare(ptr2, from_size, rounded_to_size,
+                                               junk_buf, stats.page_size));
         }
         moz_arena_free(arena, ptr2);
         moz_arena_free(arena, avoid_inplace);
@@ -599,15 +575,15 @@ TEST(Jemalloc, JunkPoison)
         ASSERT_NE(ptr, ptr2);
         if (from_size <= stats.large_max) {
           ASSERT_NO_FATAL_FAILURE(
-            bulk_compare(ptr, 0, from_size, poison_buf, stats.page_size));
+              bulk_compare(ptr, 0, from_size, poison_buf, stats.page_size));
         }
         ASSERT_NO_FATAL_FAILURE(
-          bulk_compare(ptr2, 0, to_size, fill_buf, stats.page_size));
+            bulk_compare(ptr2, 0, to_size, fill_buf, stats.page_size));
         if (stats.opt_junk || stats.opt_zero) {
           size_t rounded_to_size = malloc_good_size(to_size);
           ASSERT_NE(to_size, rounded_to_size);
-          ASSERT_NO_FATAL_FAILURE(bulk_compare(
-            ptr2, from_size, rounded_to_size, junk_buf, stats.page_size));
+          ASSERT_NO_FATAL_FAILURE(bulk_compare(ptr2, from_size, rounded_to_size,
+                                               junk_buf, stats.page_size));
         }
         moz_arena_free(arena, ptr2);
       }
