@@ -12,16 +12,14 @@
 using namespace mozilla;
 
 nsHtml5SVGLoadDispatcher::nsHtml5SVGLoadDispatcher(nsIContent* aElement)
-  : Runnable("nsHtml5SVGLoadDispatcher")
-  , mElement(aElement)
-  , mDocument(mElement->OwnerDoc())
-{
+    : Runnable("nsHtml5SVGLoadDispatcher"),
+      mElement(aElement),
+      mDocument(mElement->OwnerDoc()) {
   mDocument->BlockOnload();
 }
 
 NS_IMETHODIMP
-nsHtml5SVGLoadDispatcher::Run()
-{
+nsHtml5SVGLoadDispatcher::Run() {
   WidgetEvent event(true, eSVGLoad);
   event.mFlags.mBubbles = false;
   // Do we care about forcing presshell creation if it hasn't happened yet?
