@@ -18,14 +18,15 @@
 #include "pk11pub.h"
 #include "pkix/pkixtypes.h"
 
-namespace mozilla { namespace psm {
+namespace mozilla {
+namespace psm {
 
-struct EVInfo
-{
+struct EVInfo {
   // See bug 1338873 about making these fields const.
   const char* dottedOid;
-  const char* oidName; // Set this to null to signal an invalid structure,
-                  // (We can't have an empty list, so we'll use a dummy entry)
+  const char*
+      oidName;  // Set this to null to signal an invalid structure,
+                // (We can't have an empty list, so we'll use a dummy entry)
   unsigned char sha256Fingerprint[SHA256_LENGTH];
   const char* issuerBase64;
   const char* serialBase64;
@@ -87,6 +88,7 @@ static const size_t NUM_TEST_EV_ROOTS = 2;
 #endif
 
 static const struct EVInfo kEVInfos[] = {
+// clang-format off
   // IMPORTANT! When extending this list, if you add another entry that uses
   // the same dottedOid as an existing entry, use the same oidName.
 #ifdef DEBUG
@@ -94,8 +96,8 @@ static const struct EVInfo kEVInfos[] = {
   // 1.3.6.1.4.1.13769.666.666.666.1.500.9.1.
   // (multiple entries with the same OID is ok)
   // If you add or remove debug EV certs you must also modify NUM_TEST_EV_ROOTS
-  // so that the correct number of certs are skipped as these debug EV certs are
-  // NOT part of the default trust store.
+  // so that the correct number of certs are skipped as these debug EV certs
+  // are NOT part of the default trust store.
   {
     // This is the PSM xpcshell testing EV certificate. It can be generated
     // using pycert.py and the following specification:
@@ -1038,18 +1040,19 @@ static const struct EVInfo kEVInfos[] = {
     "ViBSb290IENlcnRpZmljYXRpb24gQXV0aG9yaXR5IFJTQSBSMg==",
     "VrYpzTS8ePY=",
   },
+    // clang-format on
 };
 
 static SECOidTag sEVInfoOIDTags[ArrayLength(kEVInfos)];
 
 static_assert(SEC_OID_UNKNOWN == 0,
-  "We depend on zero-initialized globals being interpreted as SEC_OID_UNKNOWN.");
-static_assert(ArrayLength(sEVInfoOIDTags) == ArrayLength(kEVInfos),
-  "These arrays are used in parallel and must have the same length.");
+              "We depend on zero-initialized globals being interpreted as "
+              "SEC_OID_UNKNOWN.");
+static_assert(
+    ArrayLength(sEVInfoOIDTags) == ArrayLength(kEVInfos),
+    "These arrays are used in parallel and must have the same length.");
 
-static SECOidTag
-RegisterOID(const SECItem& oidItem, const char* oidName)
-{
+static SECOidTag RegisterOID(const SECItem& oidItem, const char* oidName) {
   SECOidData od;
   od.oid.len = oidItem.len;
   od.oid.data = oidItem.data;
@@ -1062,9 +1065,7 @@ RegisterOID(const SECItem& oidItem, const char* oidName)
 
 static SECOidTag sCABForumEVOIDTag = SEC_OID_UNKNOWN;
 
-static bool
-isEVPolicy(SECOidTag policyOIDTag)
-{
+static bool isEVPolicy(SECOidTag policyOIDTag) {
   if (policyOIDTag != SEC_OID_UNKNOWN && policyOIDTag == sCABForumEVOIDTag) {
     return true;
   }
@@ -1078,19 +1079,16 @@ isEVPolicy(SECOidTag policyOIDTag)
   return false;
 }
 
-bool
-CertIsAuthoritativeForEVPolicy(const UniqueCERTCertificate& cert,
-                               const mozilla::pkix::CertPolicyId& policy)
-{
+bool CertIsAuthoritativeForEVPolicy(const UniqueCERTCertificate& cert,
+                                    const mozilla::pkix::CertPolicyId& policy) {
   MOZ_ASSERT(cert);
   if (!cert) {
     return false;
   }
 
   unsigned char fingerprint[SHA256_LENGTH];
-  SECStatus srv =
-    PK11_HashBuf(SEC_OID_SHA256, fingerprint, cert->derCert.data,
-                 AssertedCast<int32_t>(cert->derCert.len));
+  SECStatus srv = PK11_HashBuf(SEC_OID_SHA256, fingerprint, cert->derCert.data,
+                               AssertedCast<int32_t>(cert->derCert.len));
   if (srv != SECSuccess) {
     return false;
   }
@@ -1120,15 +1118,13 @@ CertIsAuthoritativeForEVPolicy(const UniqueCERTCertificate& cert,
   return false;
 }
 
-nsresult
-LoadExtendedValidationInfo()
-{
+nsresult LoadExtendedValidationInfo() {
   static const char* sCABForumOIDString = "2.23.140.1.1";
   static const char* sCABForumOIDDescription = "CA/Browser Forum EV OID";
 
   ScopedAutoSECItem cabforumOIDItem;
-  if (SEC_StringToOID(nullptr, &cabforumOIDItem, sCABForumOIDString, 0)
-        != SECSuccess) {
+  if (SEC_StringToOID(nullptr, &cabforumOIDItem, sCABForumOIDString, 0) !=
+      SECSuccess) {
     return NS_ERROR_FAILURE;
   }
   sCABForumEVOIDTag = RegisterOID(cabforumOIDItem, sCABForumOIDDescription);
@@ -1147,8 +1143,8 @@ LoadExtendedValidationInfo()
     // unnecessary to check this in non-debug builds since we will safely fall
     // back to DV if the EV information is incorrect.
     nsAutoCString derIssuer;
-    nsresult rv = Base64Decode(nsDependentCString(entry.issuerBase64),
-                               derIssuer);
+    nsresult rv =
+        Base64Decode(nsDependentCString(entry.issuerBase64), derIssuer);
     MOZ_ASSERT(NS_SUCCEEDED(rv), "Could not base64-decode built-in EV issuer");
     if (NS_FAILED(rv)) {
       return rv;
@@ -1163,10 +1159,10 @@ LoadExtendedValidationInfo()
 
     CERTIssuerAndSN ias;
     ias.derIssuer.data =
-      BitwiseCast<unsigned char*, const char*>(derIssuer.get());
+        BitwiseCast<unsigned char*, const char*>(derIssuer.get());
     ias.derIssuer.len = derIssuer.Length();
     ias.serialNumber.data =
-      BitwiseCast<unsigned char*, const char*>(serialNumber.get());
+        BitwiseCast<unsigned char*, const char*>(serialNumber.get());
     ias.serialNumber.len = serialNumber.Length();
     ias.serialNumber.type = siUnsignedInteger;
 
@@ -1213,11 +1209,10 @@ LoadExtendedValidationInfo()
 
 // Helper function for GetFirstEVPolicy(): returns the first suitable policy
 // from the given list of policies.
-bool
-GetFirstEVPolicyFromPolicyList(const UniqueCERTCertificatePolicies& policies,
-                       /*out*/ mozilla::pkix::CertPolicyId& policy,
-                       /*out*/ SECOidTag& policyOidTag)
-{
+bool GetFirstEVPolicyFromPolicyList(
+    const UniqueCERTCertificatePolicies& policies,
+    /*out*/ mozilla::pkix::CertPolicyId& policy,
+    /*out*/ SECOidTag& policyOidTag) {
   for (size_t i = 0; policies->policyInfos[i]; i++) {
     const CERTPolicyInfo* policyInfo = policies->policyInfos[i];
     SECOidTag policyInfoOID = policyInfo->oid;
@@ -1244,23 +1239,22 @@ GetFirstEVPolicyFromPolicyList(const UniqueCERTCertificatePolicies& policies,
   return false;
 }
 
-bool
-GetFirstEVPolicy(CERTCertificate& cert,
-                 /*out*/ mozilla::pkix::CertPolicyId& policy,
-                 /*out*/ SECOidTag& policyOidTag)
-{
+bool GetFirstEVPolicy(CERTCertificate& cert,
+                      /*out*/ mozilla::pkix::CertPolicyId& policy,
+                      /*out*/ SECOidTag& policyOidTag) {
   if (!cert.extensions) {
     return false;
   }
 
   for (size_t i = 0; cert.extensions[i]; i++) {
     const CERTCertExtension* extension = cert.extensions[i];
-    if (SECOID_FindOIDTag(&extension->id) != SEC_OID_X509_CERTIFICATE_POLICIES) {
+    if (SECOID_FindOIDTag(&extension->id) !=
+        SEC_OID_X509_CERTIFICATE_POLICIES) {
       continue;
     }
 
     UniqueCERTCertificatePolicies policies(
-      CERT_DecodeCertificatePoliciesExtension(&extension->value));
+        CERT_DecodeCertificatePoliciesExtension(&extension->value));
     if (!policies) {
       continue;
     }
@@ -1273,4 +1267,5 @@ GetFirstEVPolicy(CERTCertificate& cert,
   return false;
 }
 
-} } // namespace mozilla::psm
+}  // namespace psm
+}  // namespace mozilla
