@@ -9,24 +9,31 @@
 #include "nsIKeyModule.h"
 #include "pk11pub.h"
 
-#define NS_KEYMODULEOBJECT_CID   \
-{ 0x9d383ddd, 0x6856, 0x4187, {0x84, 0x85, 0xf3, 0x61, 0x95, 0xb2, 0x9a, 0x0e} }
+#define NS_KEYMODULEOBJECT_CID                       \
+  {                                                  \
+    0x9d383ddd, 0x6856, 0x4187, {                    \
+      0x84, 0x85, 0xf3, 0x61, 0x95, 0xb2, 0x9a, 0x0e \
+    }                                                \
+  }
 #define NS_KEYMODULEOBJECT_CONTRACTID "@mozilla.org/security/keyobject;1"
 
-#define NS_KEYMODULEOBJECTFACTORY_CID   \
-{ 0x2a35dd47, 0xb026, 0x4e8d, {0xb6, 0xb7, 0x57, 0x40, 0xf6, 0x1a, 0xb9, 0x02} }
+#define NS_KEYMODULEOBJECTFACTORY_CID                \
+  {                                                  \
+    0x2a35dd47, 0xb026, 0x4e8d, {                    \
+      0xb6, 0xb7, 0x57, 0x40, 0xf6, 0x1a, 0xb9, 0x02 \
+    }                                                \
+  }
 #define NS_KEYMODULEOBJECTFACTORY_CONTRACTID \
-"@mozilla.org/security/keyobjectfactory;1"
+  "@mozilla.org/security/keyobjectfactory;1"
 
-class nsKeyObject final : public nsIKeyObject
-{
-public:
+class nsKeyObject final : public nsIKeyObject {
+ public:
   nsKeyObject();
 
   NS_DECL_ISUPPORTS
   NS_DECL_NSIKEYOBJECT
 
-private:
+ private:
   ~nsKeyObject() {}
 
   // Disallow copy constructor
@@ -35,20 +42,18 @@ private:
   UniquePK11SymKey mSymKey;
 };
 
-
-class nsKeyObjectFactory final : public nsIKeyObjectFactory
-{
-public:
+class nsKeyObjectFactory final : public nsIKeyObjectFactory {
+ public:
   nsKeyObjectFactory() {}
 
   NS_DECL_THREADSAFE_ISUPPORTS
   NS_DECL_NSIKEYOBJECTFACTORY
 
-private:
+ private:
   ~nsKeyObjectFactory() {}
 
   // Disallow copy constructor
   nsKeyObjectFactory(nsKeyObjectFactory&);
 };
 
-#endif // nsKeyModule_h
+#endif  // nsKeyModule_h
