@@ -717,6 +717,6 @@ static const char flashPluginSandboxRules[] = R"SANDBOX_LITERAL(
   (deny file-write-create (vnode-type SYMLINK))
 )SANDBOX_LITERAL";
 
-}
+}  // namespace mozilla
 
-#endif // mozilla_SandboxPolicies_h
+#endif  // mozilla_SandboxPolicies_h
